Metropolis classic sampler with given covariance for RW

Metropolis(
  niter,
  covwalk,
  parinit,
  Rexp,
  tdensD,
  alpha,
  parprior,
  adaptive,
  calibration
)

Arguments

niter

number of iterations

covwalk

covariance matrix for random walk

parinit

vector of initial parameters rhos, variance of the observation noise, variance of the discrepancy and (if calibration) thetas

Rexp

residual of field data vs simulator

tdensD

output of the function tensordist

alpha

power in the exponential kernel

parprior

prior parameters for the parameters

adaptive

boolean to adapt the random walk

calibration

list of needed field if a calibration is to be performed in this order 1) computer model, 2) field observation, 3) field variable, 4) boolean indicating whether calibration is to be performed or not.

Value

Posterior sample in the transformed space