Non Linear Simulator with Calibration Parameter in any Dimension

simGal(x, theta, beta = rep(1, ncol(x)))

Arguments

x

Matrix of field design in dimension n \(\times\) p.

theta

Calibration parameter of dimension 3

beta

binary vector. Same size as theta indicating with 1 which dimensions are active

Value

vector of responses corresponding to a linearized Sobol function