BFbridgeIS.RdCompute Bayes Factor from Importance Sampling
BFbridgeIS(ech, gamma, gammaref = rep(1, length(gamma)))
| ech | posterior sample in the logit scale |
|---|---|
| gamma | values given the alpha parameter of the prior distribution on the range parameters |
| gammaref | values of the reference model, by default 1 for all range parameters |
Bayes factor between model with prior given in gamma and reference model (gamma=1)