simGal.RdNon Linear Simulator with Calibration Parameter in any Dimension
simGal(x, theta, beta = rep(1, ncol(x)))
| x | Matrix of field design in dimension n \(\times\) p. |
|---|---|
| theta | Calibration parameter of dimension 3 |
| beta | binary vector. Same size as |
vector of responses corresponding to a linearized Sobol function